dss-0.1.3.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index 508bbf9312d9f2a343ac2af265799677a372c6a0..0ebc4d28d24f423fc358385225d53d6bc7bdb878 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2009 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -90,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
 
 /**
* Get the oldest snapshot in a snapshot list.
  */
-_static_inline_ struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
+_static_inline_ struct snapshot *get_newest_snapshot(struct snapshot_list *sl)
 {
        if (!sl->num_snapshots)
                return NULL;
-       return sl->snapshots[0];
+       return sl->snapshots[sl->num_snapshots - 1];
 }
@@ -90,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 
 /**
- * Get the oldest snapshot in a snapshot list.
+ * Get the newest snapshot in a snapshot list.
  */